<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use JchOptimize\Core\Admin\Tasks;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;

class RestoreImages extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;

    public function __construct(?Input $input = null)
    {
        parent::__construct($input, null);
    }

    public function execute()
    {
        $mResult = Tasks::restoreBackupImages();
        if ('SOMEIMAGESDIDNTRESTORE' === $mResult) {
            $this->logger->warning(\__('Failed restoring all original images', 'jch-optimize'));
        } elseif ('BACKUPPATHDOESNTEXIST' === $mResult) {
            $this->logger->warning(\__('The folder containing backup images wasn\'t created yet. Try optimizing some images first.', 'jch-optimize'));
        } else {
            $this->logger->success(\__('Successfully restored all images', 'jch-optimize'));
        }
        \wp_redirect('options-general.php?page=jch_optimize&tab=optimizeimages');

        exit;
    }
}
