<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Platform;

\defined('_WP_EXEC') or exit('Restricted access');
use JchOptimize\Core\Helper;
use JchOptimize\Core\Interfaces\Profiler as ProfilerInterface;

class Profiler implements ProfilerInterface
{
    /**
     * @param string $sHtml
     * @param bool   $isAmpPage
     */
    public static function attachProfiler(&$sHtml, $isAmpPage = \false)
    {
        if (!\is_super_admin() || $isAmpPage) {
            return;
        }
        $items = \JchOptimize\Platform\Profiler::mark(\true);
        $node = self::getAdminBarNodeBegin().$items.self::getAdminBarNodeEnd();
        $cdata = Helper::isXhtml($sHtml) ? '/*<![CDATA[*/' : '';
        $script = <<<HTML
<script>{$cdata}
    const li = document.getElementById("wp-admin-bar-jch-optimize-profiler");
    if (li !== null){
        li.classList.add("menupop");
        li.innerHTML = '{$node}';
    }
{$cdata}</script>
HTML;
        $sHtml = \str_replace('</body>', $script.'</body>', $sHtml);
    }

    /**
     * @staticvar string $item
     *
     * @param string|true $text
     *
     * @return string|void
     */
    public static function mark($text)
    {
        static $item = '';
        if (\true === $text) {
            return $item;
        }
        static $last_time = 0;
        $current_time = (float) \timer_stop();
        $time_taken = $last_time > 0 ? $current_time - $last_time : 0;
        $time_taken = \function_exists('number_format_i18n') ? \number_format_i18n($time_taken, 3) : \number_format($time_taken, 3);
        $last_time = $current_time;
        $item .= self::addAdminBarItem($current_time.'  (+'.$time_taken.') - '.$text);
    }

    /**
     * @param string $text
     * @param bool   $mark
     */
    public static function start($text, $mark = \false)
    {
        if ($mark) {
            self::mark('before'.$text);
        }
    }

    /**
     * @param string $text
     * @param bool   $mark
     */
    public static function stop($text, $mark = \false)
    {
        if ($mark) {
            self::mark('after'.$text);
        }
    }

    /**
     * @param string $item
     */
    protected static function addAdminBarItem($item): string
    {
        static $counter = 0;
        ++$counter;

        return <<<HTML
<li id="wp-admin-bar-jch-optimize-profiler-item{$counter}"><div class="ab-item ab-empty-item"><a class="ab-item">{$item}</a></div></li>
HTML;
    }

    protected static function getAdminBarNodeBegin(): string
    {
        $profiler = \__('Profiler', 'jch-optimize');

        return <<<HTML
<div class="ab-item ab-empty-item" aria-haspopup="true"><span class="wp-admin-bar-arrow" aria-hidden="true"></span>{$profiler}</div><div class="ab-sub-wrapper"><ul id="wp-admin-bar-jch-optimize-profiler-default" class="ab-submenu" style="overflow:auto;max-height: 600px;">
HTML;
    }

    protected static function getAdminBarNodeEnd(): string
    {
        return '</ul></div>';
    }
}
