<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\View;

use _JchOptimizeVendor\Joomla\Registry\Registry;
use _JchOptimizeVendor\Joomla\Renderer\RendererInterface;
use _JchOptimizeVendor\Joomla\View\HtmlView;
use JchOptimize\Html\Helper;

class PageCacheHtml extends HtmlView
{
    public function __construct(RendererInterface $renderer)
    {
        parent::__construct($renderer);
        $this->setLayout('pagecache');
    }

    public function renderStatefulElements(Registry $state)
    {
        // Generate HTML for Search Input box
        // language=HTML
        $searchInput = '<input type="text" id="filter_search" name="filter[search]" class="form-control" value="'.$state->get('filter_search').'" placeholder="Search by URL" aria-label="Search by URL" aria-describedby="filter-search-button">';
        $this->addData('searchInput', $searchInput);
        // Generate HTML for filter time 1
        $filterTime1Options = ['' => '- Filter by Start Time -', '900' => '>= 15 mins ago', '1800' => '>= 30 mins ago ', '3600' => '>= 1 hour ago', '10800' => '>= 3 hours ago', '21600' => '>= 6 hours ago', '43200' => '>= 12 hours ago', '86400' => '>= 1 day ago', '172800' => '>= 2 days ago', '604800' => '>= 1 week ago', '1209600' => '>= 2 weeks ago'];
        $filterTime1OptionsHtml = Helper::option($filterTime1Options, $state->get('filter_time-1', null));
        $filterTime1SelectHtml = $this->selectListGenerator('filter', $filterTime1OptionsHtml, 'time-1');
        $this->addData('filterTime1SelectHtml', $filterTime1SelectHtml);
        // Generate HTML for filter time 2
        $filterTime2Options = ['' => '- Filter by End Time -', '900' => '< 15 mins ago', '1800' => '< 30 mins ago', '3600' => '< 1 hour ago', '10800' => '< 3 hours ago', '21600' => '< 6 hours ago', '43200' => '< 12 hours ago', '86400' => '< 1 day ago', '172800' => '< 2 days ago', '604800' => '< 1 week ago', '1209600' => '< 2 weeks ago'];
        $filterTime2OptionsHtml = Helper::option($filterTime2Options, $state->get('filter_time-2', null));
        $filterTime2SelectHtml = $this->selectListGenerator('filter', $filterTime2OptionsHtml, 'time-2');
        $this->addData('filterTime2SelectHtml', $filterTime2SelectHtml);
        // Generate HTML for filter device
        $deviceOptions = ['' => '- Filter by device -', 'Mobile' => 'Mobile', 'Desktop' => 'Desktop'];
        $filterDeviceOptionsHtml = Helper::option($deviceOptions, $state->get('filter_device', null));
        $filterDeviceSelectHtml = $this->selectListGenerator('filter', $filterDeviceOptionsHtml, 'device');
        $this->addData('filterDeviceSelectHtml', $filterDeviceSelectHtml);
        // Generate HTML for filter adapter
        $filterAdapterOptions = ['' => '- Filter by Adapter -', 'Filesystem' => 'Filesystem', 'Redis' => 'Redis', 'Apcu' => 'APCu', 'Memcached' => 'Memcached', 'Wincache' => 'Wincache'];
        $filterAdapterOptionsHtml = Helper::option($filterAdapterOptions, $state->get('filter_adapter', null));
        $filterAdapterSelectHtml = $this->selectListGenerator('filter', $filterAdapterOptionsHtml, 'adapter');
        $this->addData('filterAdapterSelectHtml', $filterAdapterSelectHtml);
        // Generate HTML for filter HTTP Request
        $filterHttpRequestOptions = ['' => '- Filter by HTTP Request -', 'yes' => 'Yes', 'no' => 'No'];
        $filterHttpRequestOptionsHtml = Helper::option($filterHttpRequestOptions, $state->get('filter_http-request', null));
        $filterHttpRequestSelectHtml = $this->selectListGenerator('filter', $filterHttpRequestOptionsHtml, 'http-request');
        $this->addData('filterHttpRequestSelectHtml', $filterHttpRequestSelectHtml);
        // Generate option value for ordering list
        $orderOptions = ['' => 'Sort Table By:', 'mtime_asc' => 'Last modified time ascending', 'mtime_desc' => 'Last modified time descending', 'url_asc' => 'Page URL ascending', 'url_desc' => 'Page URL descending'];
        $orderOptionsHtml = Helper::option($orderOptions, $state->get('list_fullordering', null));
        $this->addData('orderOptionsHtml', $orderOptionsHtml);
        // Generate option values for limit list
        $limitOptions = ['5' => '5', '10' => '10', '15' => '15', '20' => '20', '25' => '25', '30' => '30', '50' => '50', '100' => '100', '200' => '200', '500' => '500', '-1' => 'All'];
        $limitOptionsHtml = Helper::option($limitOptions, $state->get('list_limit', '20'));
        $this->addData('limitOptionsHtml', $limitOptionsHtml);
    }

    public function loadResources()
    {
        $js = <<<JS
document.addEventListener("DOMContentLoaded", function(){
\tvar tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
\tvar tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
  \t\treturn new bootstrap.Tooltip(tooltipTriggerEl,{
      \t\t\tplacement: 'right'
  \t\t})
\t})
});
JS;
        \wp_add_inline_script('jch-bootstrap-js', $js);
    }

    private function selectListGenerator(string $type, string $optionsHtml, string $value): string
    {
        return <<<HTML
<select id="{$type}_{$value}" name="{$type}[{$value}]" class="ms-2" onchange="this.form.submit();"
                aria-label="{$type} {$value}">
            {$optionsHtml}
        </select>
HTML;
    }
}
